@@ -2,6 +2,47 @@ import requests
 import settings
 
 
+def generate_curl(request):
+    command = "curl --compressed -X {method} -H {headers} -d '{data}' '{uri}'"
+
+    method = request.method
+
+    headers = ['"{0}: {1}"'.format(k, v) for k, v in request.headers.items()]
+    headers = " -H ".join(headers)
+
+    data = request.body
+    uri = request.url
+
+    return command.format(method=method, headers=headers, data=data, uri=uri)
+
+
+def log_curl(func):
+    def wrapper(*args, **kw):
+        self = None
+        from . import base_testcase
+
+        for item in args:
+            if isinstance(item, base_testcase.BaseTestCase):
+                self = item
+                break
+
+        res = func(*args, **kw)
+
+        if self:
+            self.logger.info("================================ cURL Start ==========================\n")
+            self.logger.info(generate_curl(res.request))
+            self.logger.info("================================ cURL End ============================\n")
+        else:
+            # todo
+            print("原生requests调用。。。 此处直接讲cURL输出到控制台 ?")
+            print("================================ cURL Start ==========================\n")
+            print(generate_curl(res.request))
+            print("================================ cURL End ============================\n")
+        return res
+
+    return wrapper
+
+
 class LoggedRequests:
     """
     封装 requests module 的常用方法，自动log 每次 request 的参数 & response 内容
@@ -9,6 +50,7 @@ class LoggedRequests:
     """
 
     @staticmethod
+    @log_curl
     def get(self=None, url=None, params=None, **kwargs):
         '''
         self， 如果为None, 则此方法 等价于 开源 requests.get()方法， 否则 会自动写入 此请求的参数 & 响应值
@@ -61,6 +103,7 @@ class LoggedRequests:
         return response
 
     @staticmethod
+    @log_curl
     def post(self=None, url=None, data=None, json=None, **kwargs):
         '''
         self， 如果为None, 则此方法 等价于 开源 requests.post()方法， 否则 会自动写入 此请求的参数 & 响应值
@@ -71,6 +114,7 @@ class LoggedRequests:
 
             # 直接调用 开源 requests
             response = requests.post(url, data, json, **kwargs)
+
             return response
 
         if self is None:
@@ -115,7 +159,6 @@ class LoggedRequests:
         self.logger.info("\n<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< Response:")
         self.logger.info(response)
 
-
         # todo
         if response.status_code == 200:
             self.logger.info(response)
@@ -124,13 +167,24 @@ class LoggedRequests:
                 self.logger.info(self.pformat(response.json()))
             except BaseException:
                 self.logger.info(response.__dict__)
+
+                # todo
+                # self.logger.info("================================ cURL Start ==========================\n")
+                # self.logger.info(generate_curl(response.request))
+                # self.logger.info("================================ cURL End ============================\n")
                 return response
 
         self.logger.info("\n\n")
 
+        # print(generate_curl(response.request))
+        # self.logger.info("================================ cURL Start ==========================\n")
+        # self.logger.info(generate_curl(response.request))
+        # self.logger.info("================================ cURL End ============================\n")
+
         return response
 
     @staticmethod
+    @log_curl
     def put(self=None, url=None, data=None, **kwargs):
         '''
         self， 如果为None, 则此方法 等价于 开源 requests.put()方法， 否则 会自动写入 此请求的参数 & 响应值
@@ -180,6 +234,7 @@ class LoggedRequests:
         return response
 
     @staticmethod
+    @log_curl
     def delete(self=None, url=None, **kwargs):
         '''
         self， 如果为None, 则此方法 等价于 开源 requests.delete()方法， 否则 会自动写入 此请求的参数 & 响应值
